# A plug-in for knowledge distillation
[![codecov](https://codecov.io/gh/Jingnan-Jia/kd_med/branch/master/graph/badge.svg?token=Z808SDKUFQ)](https://codecov.io/gh/Jingnan-Jia/kd_med)
![example workflow](https://github.com/Jingnan-Jia/kd_med/actions/workflows/test_and_publish.yml/badge.svg)
